<?php

namespace Drupal\cm_revision_delete\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class NodeRevisionDeleteAdminSettingsForm.
 *
 * Admin config form definition.
 *
 * @package Drupal\node_revision_delete\Form
 */
class DevelForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'cm_revision_delete.devel',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'cm_revision_delete_devel';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('cm_revision_delete.devel');
    $moduleHandler = \Drupal::service('module_handler');

    if ($moduleHandler->moduleExists('devel')) {
      if (!empty($config->get('nid'))) {
        $this->getRevisionsToDelete($config);
      }
    }
    else {
      \Drupal::messenger()->addWarning(t('This page required the devel module to be enabled.'));
    }

    $langcodes = \Drupal::languageManager()->getLanguages();
    $languages = array_keys($langcodes);
    $lang_options = [];

    foreach ($languages as $key => $lang) {
      $lang_options[$lang] = $lang;
    }

    $form['devel'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Devel settings'),
      '#description' => $this->t('This form allow you to test the revision candidate algorythm. The revisions returned are candidates for deletion.'),
    ];

    $form['devel']['nid'] = array(
      '#type' => 'number',
      '#title' => $this->t('Node ID'),
      '#description' => $this->t('Enter a nid to test.'),
      '#default_value' => $config->get('nid'),
      '#required' => TRUE,
    );

    $form['devel']['language'] = array(
      '#type' => 'select',
      '#title' => $this->t('Language'),
      '#options' => $lang_options,
      '#default_value' => $config->get('language'),
      '#required' => TRUE,
    );

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('cm_revision_delete.devel')
      ->set('nid', $form_state->getValue('nid'))
      ->set('language', $form_state->getValue('language'))
      ->save();
  }

  public function getRevisionsToDelete($config) {
    $settings_config = \Drupal::config('cm_revision_delete.settings');
    $nid = $config->get('nid');
    $lang = $config->get('language');
    $limit = $settings_config->get('cm_revision_delete_revisions');

    $revisions = cm_revision_delete_get_revisions($nid, $lang, $limit);
    $is_node_candidate = cm_revision_delete_get_node_candidate($nid);

    $revision_array = [];
    \Drupal::messenger()->deleteAll();

    if (!empty($is_node_candidate)) {
      dpm('This node is a candidate for processing.');

      foreach ($revisions as $key => $vid) {
        $revision = \Drupal::entityTypeManager()->getStorage('node')->loadRevision($vid);

        if ($revision->hasTranslation($lang)) {
          $revision = $revision->getTranslation($lang);
        }

        $revision_array[$vid] = $revision->get('moderation_state')->getString();
      }

      krsort($revision_array);

      dpm($revision_array);
    }
    else {
      dpm('This node is NOT a candidate for processing.');
    }
  }

}
